@@ -1,14 +1,14 @@
 forest.orbbound <- function(x,
-                            comb.fixed=x$x$comb.fixed,
-                            comb.random=x$x$comb.random,
-                            text.fixed="FE model",
-                            text.random="RE model",
-                            smlab=NULL,
-                            leftcols=c("studlab", "maxbias"),
-                            leftlabs=c("Missing\nstudies", "Maximum\nbias"),
-                            backtransf=x$backtransf,
-                            digits=max(3, .Options$digits - 3),
-                            ...){
+                            comb.fixed = x$x$comb.fixed,
+                            comb.random = x$x$comb.random,
+                            text.fixed = "FE model",
+                            text.random = "RE model",
+                            smlab = NULL,
+                            leftcols = c("studlab", "maxbias"),
+                            leftlabs = c("Missing\nstudies", "Maximum\nbias"),
+                            backtransf = x$backtransf,
+                            digits = max(3, .Options$digits - 3),
+                            ...) {
   
   meta:::chkclass(x, "orbbound")
   
@@ -21,7 +21,7 @@ forest.orbbound <- function(x,
   ##
   fun <- "print.summary.limitmeta"
   ##
-  meta:::warnarg("logscale", addargs, fun, otherarg="backtransf")
+  meta:::warnarg("logscale", addargs, fun, otherarg = "backtransf")
   ##
   if (is.null(backtransf))
     if (!is.null(list(...)[["logscale"]]))
@@ -30,27 +30,27 @@ forest.orbbound <- function(x,
       backtransf <- TRUE
   
   
-  if (length(comb.fixed)==0)
+  if (length(comb.fixed) == 0)
     comb.fixed <- TRUE
   ##
-  if (length(comb.random)==0)
+  if (length(comb.random) == 0)
     comb.random <- TRUE
   
   
   sm.lab <- sm
   ##
-  if (backtransf){
-    if (sm=="ZCOR")
+  if (backtransf) {
+    if (sm == "ZCOR")
       sm.lab <- "COR"
     if (sm %in% c("PFT", "PAS", "PRAW", "PLOGIT", "PLN"))
       sm.lab <- "proportion"
   }
   else 
     if (meta:::is.relative.effect(sm))
-      sm.lab <- paste("log", sm, sep="")
+      sm.lab <- paste("log", sm, sep = "")
   
   
-  ci.lab <- paste(round(100*x$x$level.comb, 1), "%-CI", sep="")
+  ci.lab <- paste(round(100 * x$x$level.comb, 1), "%-CI", sep = "")
   
   
   TE.fixed   <- x$fixed$TE
@@ -60,63 +60,63 @@ forest.orbbound <- function(x,
   seTE.random <- rep(x$random$seTE, length(TE.random))
   
   
-  if (comb.fixed & comb.random){
+  if (comb.fixed & comb.random) {
     TE <- c(TE.fixed, TE.random)
     seTE <- c(seTE.fixed, seTE.random)
     FEvsRE <- c(rep(text.fixed, length(TE.fixed)),
                 rep(text.random, length(TE.random)))
   }
-  if (comb.fixed & !comb.random){
+  if (comb.fixed & !comb.random) {
     TE <- TE.fixed
     seTE <- seTE.fixed
     if (is.null(smlab))
       smlab <- "Fixed effect model"
   }
-  if (!comb.fixed & comb.random){
+  if (!comb.fixed & comb.random) {
     TE <- TE.random
     seTE <- seTE.random
     if (is.null(smlab))
       smlab <- "Random effects model"
   }
-  if (!comb.fixed & !comb.random){
+  if (!comb.fixed & !comb.random) {
     warning("No forest plot generated as both arguments 'comb.fixed' and 'comb.random' are FALSE")
     return(invisible(NULL))
   }
   
   
   if (comb.fixed & comb.random)
-    m1 <- metagen(TE, seTE, sm=sm.lab,
-                  byvar=FEvsRE, print.byvar=FALSE,
-                  warn=FALSE)
+    m1 <- metagen(TE, seTE, sm = sm.lab,
+                  byvar = FEvsRE, print.byvar = FALSE,
+                  warn = FALSE)
   else
-    m1 <- metagen(TE, seTE, sm=sm.lab, warn=FALSE)
+    m1 <- metagen(TE, seTE, sm = sm.lab, warn = FALSE)
   ##
-  if (comb.fixed & comb.random){
+  if (comb.fixed & comb.random) {
     m1$studlab <- c(x$k.suspect, x$k.suspect)
     m1$maxbias <- c(x$maxbias, x$maxbias)
-    m1$npft.ma <- c(1/mean(1/x$x$n), 1/mean(1/x$x$n))
+    m1$npft.ma <- c(1 / mean(1 / x$x$n), 1 / mean(1 / x$x$n))
   }
-  else{
+  else {
     m1$studlab <- x$k.suspect
     m1$maxbias <- x$maxbias
-    m1$npft.ma <- 1/mean(1/x$x$n)
+    m1$npft.ma <- 1 / mean(1 / x$x$n)
   }
   
   
   if (backtransf)
     m1$maxbias <- meta:::backtransf(m1$maxbias, sm, "mean",
-                                    m1$npft.ma, warn=FALSE)
+                                    m1$npft.ma, warn = FALSE)
   ##
   m1$maxbias <- format(round(m1$maxbias, digits))
   
   forest(m1,
-         comb.fixed=FALSE, comb.random=FALSE,
-         hetstat=FALSE,
-         leftcols=leftcols,
-         leftlabs=leftlabs,
-         smlab=smlab,
-         just.studlab="center",
-         weight="same",
+         comb.fixed = FALSE, comb.random = FALSE,
+         hetstat = FALSE,
+         leftcols = leftcols,
+         leftlabs = leftlabs,
+         smlab = smlab,
+         just.studlab = "center",
+         weight.study = "same",
          ...)
   
   
