@@ -1,8 +1,6 @@
-.onAttach <-
-function (libname, pkgname) 
-{
+.onAttach <- function(libname, pkgname) {
   msg <- paste("Loading 'metasens' package (version ",
                utils::packageDescription("metasens")$Version,
-               ").", sep="")
+               ").", sep = "")
   packageStartupMessage(msg)
 }
